==> haskell-servant-client-core-0.20.3.0-24-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-5BHxo0Ia21sJywxtZFJ4Oy
key:                  servant-client-core-0.20.3.0-5BHxo0Ia21sJywxtZFJ4Oy
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  5e81864966f928a190a64737eba22260
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-5BHxo0Ia21sJywxtZFJ4Oy
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4
    attoparsec-0.14.4-5QXKAIXHnspGYO0JElIsOr base-4.17.2.1
    base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 constraints-0.14.2-1KE1LtvelHoEkOUj9iZnlO
    containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5
    free-5.2-2RtOTHKFvJpH8282U4t1Yu
    http-media-0.8.1.1-ED6TwhQl5UP62bsOUkVBr3
    http-types-0.12.4-BqXeLjMsy2zE8Q8bHBFhrt
    network-uri-2.6.4.2-4IxerK0JG7wGRLJekUQEdr
    safe-0.3.21-ByjvVtJLwt5KrRntZowDKh
    servant-0.20.3.0-GoDzgAX79y3uyRklT1hd7
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-servant-client-core-0.20.3.0-25-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-servant-client-core.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 servant-client-core
version:              0.20.3.0
visibility:           public
id:                   servant-client-core-0.20.3.0-7g5nZcoAafQCeIsB1WbBWu
key:                  servant-client-core-0.20.3.0-7g5nZcoAafQCeIsB1WbBWu
license:              BSD-3-Clause
copyright:
    2014-2016 Zalora South East Asia Pte Ltd, 2016-2019 Servant Contributors

maintainer:           haskell-servant-maintainers@googlegroups.com
author:               Servant Contributors
homepage:             http://docs.servant.dev/
synopsis:
    Core functionality and class for client function generation for servant APIs

description:
    This library provides backend-agnostic generation of client functions. For
    more information, see the README.

category:             Servant, Web
abi:                  cff16ee7d8d904211f59f2b20242dbb6
exposed:              True
exposed-modules:
    Servant.Client.Core Servant.Client.Core.Auth
    Servant.Client.Core.BaseUrl Servant.Client.Core.BasicAuth
    Servant.Client.Core.ClientError Servant.Client.Core.HasClient
    Servant.Client.Core.MultiVerb.ResponseUnrender
    Servant.Client.Core.Reexport Servant.Client.Core.Request
    Servant.Client.Core.Response Servant.Client.Core.RunClient
    Servant.Client.Core.ServerSentEvents Servant.Client.Free
    Servant.Client.Generic

hidden-modules:       Servant.Client.Core.Internal
import-dirs:          /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs:         /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
library-dirs-static:  /usr/lib/ghc-9.4.8/site-local/servant-client-core-0.20.3.0
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-servant-client-core
hs-libraries:         HSservant-client-core-0.20.3.0-7g5nZcoAafQCeIsB1WbBWu
depends:
    aeson-2.1.2.1-CoFGCad0PesDH4XC5ctCv4
    attoparsec-0.14.4-5QXKAIXHnspGYO0JElIsOr base-4.17.2.1
    base-compat-0.14.0-D6ySGt5shRqHRPQXrHl9Oo
    base64-bytestring-1.2.1.0-H7PD9x3a1R75H5UmP3m5CT
    bytestring-0.11.5.3 constraints-0.14.2-1KE1LtvelHoEkOUj9iZnlO
    containers-0.6.7 deepseq-1.4.8.0 exceptions-0.10.5
    free-5.2-2RtOTHKFvJpH8282U4t1Yu
    http-media-0.8.1.1-ED6TwhQl5UP62bsOUkVBr3
    http-types-0.12.4-BqXeLjMsy2zE8Q8bHBFhrt
    network-uri-2.6.4.2-4IxerK0JG7wGRLJekUQEdr
    safe-0.3.21-ByjvVtJLwt5KrRntZowDKh
    servant-0.20.3.0-FAtRB7rD5uIha6J7hegNi
    sop-core-0.5.0.2-6A7lf58QPy2GZuvhMdgskj template-haskell-2.19.0.0
    text-2.0.2

haddock-interfaces:
    /usr/share/doc/haskell-servant-client-core/html/servant-client-core.haddock

haddock-html:         /usr/share/doc/haskell-servant-client-core/html
' | '/usr/bin/ghc-pkg-9.4.8' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
